==> libg++-1.36.3.tar.bz2: libg++-1.36.3/etc/trie-gen/main.cc <==
/* Driver routine for the minimal-prefix trie generator.

   Copyright (C) 1989 Free Software Foundation, Inc.
   written by Douglas C. Schmidt (schmidt@ics.uci.edu)
   
   This file is part of GNU TRIE-GEN.
   
   GNU TRIE-GEN is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 1, or (at your option)
   any later version.
   
   GNU TRIE-GEN is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with GNU trie-gen; see the file COPYING.  If not, write to
   the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */

#include <sys/resource.h>
#include <File.h>
#include "trie.h"

/* Simple-minded flag controls the whether compact is performed.
   Soon to be replaced with a more complete set of options. */
int compact;

int
main (int argc, char **argv)
{
  if (argc > 1)
    compact = 1;

#ifdef UNLIMIT_STACK
  /* Get rid of any avoidable limit on stack size.  */
  {
    struct rlimit rlim;

    /* Set the stack limit huge so that alloca does not fail. */
    getrlimit (RLIMIT_STACK, &rlim);
    rlim.rlim_cur = rlim.rlim_max;
    setrlimit (RLIMIT_STACK, &rlim);
  }
#endif /* UNLIMIT_STACK */

  File  input (stdin);
  Trie  Trie (Trie::DEFAULT_SIZE, compact);
  char *buf;

  for (int i = 0; input.gets (&buf); i++)
    Trie.insert (buf, input.iocount ());

  Trie.output ();
}

==> libg++-1.39.0.tar.bz2: libg++-1.39.0/etc/trie-gen/main.cc <==
/* Driver routine for the minimal-prefix trie generator.

   Copyright (C) 1989 Free Software Foundation, Inc.
   written by Douglas C. Schmidt (schmidt@ics.uci.edu)
   
   This file is part of GNU TRIE-GEN.
   
   GNU TRIE-GEN is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 1, or (at your option)
   any later version.
   
   GNU TRIE-GEN is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with GNU trie-gen; see the file COPYING.  If not, write to
   the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */

#include <sys/resource.h>
#include <File.h>
#include "options.h"
#include "trie.h"

int
main (int argc, char **argv)
{
  option (argc, argv);

#ifdef UNLIMIT_STACK
  /* Get rid of any avoidable limit on stack size.  */
  {
    struct rlimit rlim;

    /* Set the stack limit huge so that alloca does not fail. */
    getrlimit (RLIMIT_STACK, &rlim);
    rlim.rlim_cur = rlim.rlim_max;
    setrlimit (RLIMIT_STACK, &rlim);
  }
#endif /* UNLIMIT_STACK */

  File  input (stdin);
  Trie  Trie (Trie::DEFAULT_SIZE);
  char *buf;

  for (int i = 0; input.gets (&buf); i++)
    Trie.insert (buf, input.iocount ());

  Trie.output ();
}
